# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ActiveRoleAssignmentSchedule',
    'ActiveRoleAssignmentScheduleExpiration',
    'ActiveRoleAssignmentTicket',
    'EligibleRoleAssignmentSchedule',
    'EligibleRoleAssignmentScheduleExpiration',
    'EligibleRoleAssignmentTicket',
    'RoleManagementPolicyActivationRules',
    'RoleManagementPolicyActivationRulesApprovalStage',
    'RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover',
    'RoleManagementPolicyActiveAssignmentRules',
    'RoleManagementPolicyEligibleAssignmentRules',
    'RoleManagementPolicyNotificationRules',
    'RoleManagementPolicyNotificationRulesActiveAssignments',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications',
    'RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications',
    'RoleManagementPolicyNotificationRulesEligibleActivations',
    'RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications',
    'RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications',
    'RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications',
    'RoleManagementPolicyNotificationRulesEligibleAssignments',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications',
    'RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications',
    'GetRoleManagementPolicyActivationRuleResult',
    'GetRoleManagementPolicyActivationRuleApprovalStageResult',
    'GetRoleManagementPolicyActivationRuleApprovalStagePrimaryApproverResult',
    'GetRoleManagementPolicyActiveAssignmentRuleResult',
    'GetRoleManagementPolicyEligibleAssignmentRuleResult',
    'GetRoleManagementPolicyNotificationRuleResult',
    'GetRoleManagementPolicyNotificationRuleActiveAssignmentResult',
    'GetRoleManagementPolicyNotificationRuleActiveAssignmentAdminNotificationResult',
    'GetRoleManagementPolicyNotificationRuleActiveAssignmentApproverNotificationResult',
    'GetRoleManagementPolicyNotificationRuleActiveAssignmentAssigneeNotificationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleActivationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleActivationAdminNotificationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleActivationApproverNotificationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleActivationAssigneeNotificationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleAssignmentResult',
    'GetRoleManagementPolicyNotificationRuleEligibleAssignmentAdminNotificationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleAssignmentApproverNotificationResult',
    'GetRoleManagementPolicyNotificationRuleEligibleAssignmentAssigneeNotificationResult',
]

@pulumi.output_type
class ActiveRoleAssignmentSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "startDateTime":
            suggest = "start_date_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ActiveRoleAssignmentSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ActiveRoleAssignmentSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ActiveRoleAssignmentSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expiration: Optional['outputs.ActiveRoleAssignmentScheduleExpiration'] = None,
                 start_date_time: Optional[str] = None):
        """
        :param 'ActiveRoleAssignmentScheduleExpirationArgs' expiration: An `expiration` block as defined above.
        :param str start_date_time: The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if start_date_time is not None:
            pulumi.set(__self__, "start_date_time", start_date_time)

    @property
    @pulumi.getter
    def expiration(self) -> Optional['outputs.ActiveRoleAssignmentScheduleExpiration']:
        """
        An `expiration` block as defined above.
        """
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter(name="startDateTime")
    def start_date_time(self) -> Optional[str]:
        """
        The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "start_date_time")


@pulumi.output_type
class ActiveRoleAssignmentScheduleExpiration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "durationDays":
            suggest = "duration_days"
        elif key == "durationHours":
            suggest = "duration_hours"
        elif key == "endDateTime":
            suggest = "end_date_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ActiveRoleAssignmentScheduleExpiration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ActiveRoleAssignmentScheduleExpiration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ActiveRoleAssignmentScheduleExpiration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration_days: Optional[int] = None,
                 duration_hours: Optional[int] = None,
                 end_date_time: Optional[str] = None):
        """
        :param int duration_days: The duration of the role assignment in days. Changing this forces a new resource to be created.
        :param int duration_hours: The duration of the role assignment in hours. Changing this forces a new resource to be created.
        :param str end_date_time: The end date/time of the role assignment. Changing this forces a new resource to be created.
               
               > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        if duration_days is not None:
            pulumi.set(__self__, "duration_days", duration_days)
        if duration_hours is not None:
            pulumi.set(__self__, "duration_hours", duration_hours)
        if end_date_time is not None:
            pulumi.set(__self__, "end_date_time", end_date_time)

    @property
    @pulumi.getter(name="durationDays")
    def duration_days(self) -> Optional[int]:
        """
        The duration of the role assignment in days. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_days")

    @property
    @pulumi.getter(name="durationHours")
    def duration_hours(self) -> Optional[int]:
        """
        The duration of the role assignment in hours. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_hours")

    @property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> Optional[str]:
        """
        The end date/time of the role assignment. Changing this forces a new resource to be created.

        > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        return pulumi.get(self, "end_date_time")


@pulumi.output_type
class ActiveRoleAssignmentTicket(dict):
    def __init__(__self__, *,
                 number: Optional[str] = None,
                 system: Optional[str] = None):
        """
        :param str number: User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        :param str system: User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        if number is not None:
            pulumi.set(__self__, "number", number)
        if system is not None:
            pulumi.set(__self__, "system", system)

    @property
    @pulumi.getter
    def number(self) -> Optional[str]:
        """
        User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "number")

    @property
    @pulumi.getter
    def system(self) -> Optional[str]:
        """
        User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system")


@pulumi.output_type
class EligibleRoleAssignmentSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "startDateTime":
            suggest = "start_date_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EligibleRoleAssignmentSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EligibleRoleAssignmentSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EligibleRoleAssignmentSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expiration: Optional['outputs.EligibleRoleAssignmentScheduleExpiration'] = None,
                 start_date_time: Optional[str] = None):
        """
        :param 'EligibleRoleAssignmentScheduleExpirationArgs' expiration: An `expiration` block as defined above.
        :param str start_date_time: The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        if expiration is not None:
            pulumi.set(__self__, "expiration", expiration)
        if start_date_time is not None:
            pulumi.set(__self__, "start_date_time", start_date_time)

    @property
    @pulumi.getter
    def expiration(self) -> Optional['outputs.EligibleRoleAssignmentScheduleExpiration']:
        """
        An `expiration` block as defined above.
        """
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter(name="startDateTime")
    def start_date_time(self) -> Optional[str]:
        """
        The start date/time of the role assignment. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "start_date_time")


@pulumi.output_type
class EligibleRoleAssignmentScheduleExpiration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "durationDays":
            suggest = "duration_days"
        elif key == "durationHours":
            suggest = "duration_hours"
        elif key == "endDateTime":
            suggest = "end_date_time"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in EligibleRoleAssignmentScheduleExpiration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        EligibleRoleAssignmentScheduleExpiration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        EligibleRoleAssignmentScheduleExpiration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration_days: Optional[int] = None,
                 duration_hours: Optional[int] = None,
                 end_date_time: Optional[str] = None):
        """
        :param int duration_days: The duration of the role assignment in days. Changing this forces a new resource to be created.
        :param int duration_hours: The duration of the role assignment in hours. Changing this forces a new resource to be created.
        :param str end_date_time: The end date/time of the role assignment. Changing this forces a new resource to be created.
               
               > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        if duration_days is not None:
            pulumi.set(__self__, "duration_days", duration_days)
        if duration_hours is not None:
            pulumi.set(__self__, "duration_hours", duration_hours)
        if end_date_time is not None:
            pulumi.set(__self__, "end_date_time", end_date_time)

    @property
    @pulumi.getter(name="durationDays")
    def duration_days(self) -> Optional[int]:
        """
        The duration of the role assignment in days. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_days")

    @property
    @pulumi.getter(name="durationHours")
    def duration_hours(self) -> Optional[int]:
        """
        The duration of the role assignment in hours. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "duration_hours")

    @property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> Optional[str]:
        """
        The end date/time of the role assignment. Changing this forces a new resource to be created.

        > Note: Only one of `duration_days`, `duration_hours` or `end_date_time` should be specified.
        """
        return pulumi.get(self, "end_date_time")


@pulumi.output_type
class EligibleRoleAssignmentTicket(dict):
    def __init__(__self__, *,
                 number: Optional[str] = None,
                 system: Optional[str] = None):
        """
        :param str number: User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        :param str system: User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        if number is not None:
            pulumi.set(__self__, "number", number)
        if system is not None:
            pulumi.set(__self__, "system", system)

    @property
    @pulumi.getter
    def number(self) -> Optional[str]:
        """
        User-supplied ticket number to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "number")

    @property
    @pulumi.getter
    def system(self) -> Optional[str]:
        """
        User-supplied ticket system name to be included with the request. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system")


@pulumi.output_type
class RoleManagementPolicyActivationRules(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "approvalStage":
            suggest = "approval_stage"
        elif key == "maximumDuration":
            suggest = "maximum_duration"
        elif key == "requireApproval":
            suggest = "require_approval"
        elif key == "requireJustification":
            suggest = "require_justification"
        elif key == "requireMultifactorAuthentication":
            suggest = "require_multifactor_authentication"
        elif key == "requireTicketInfo":
            suggest = "require_ticket_info"
        elif key == "requiredConditionalAccessAuthenticationContext":
            suggest = "required_conditional_access_authentication_context"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyActivationRules. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyActivationRules.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyActivationRules.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 approval_stage: Optional['outputs.RoleManagementPolicyActivationRulesApprovalStage'] = None,
                 maximum_duration: Optional[str] = None,
                 require_approval: Optional[bool] = None,
                 require_justification: Optional[bool] = None,
                 require_multifactor_authentication: Optional[bool] = None,
                 require_ticket_info: Optional[bool] = None,
                 required_conditional_access_authentication_context: Optional[str] = None):
        """
        :param 'RoleManagementPolicyActivationRulesApprovalStageArgs' approval_stage: An `approval_stage` block as defined below.
        :param str maximum_duration: The maximum length of time an activated role can be valid, in an ISO8601 Duration format (e.g. `PT8H`). Valid range is `PT30M` to `PT23H30M`, in 30 minute increments, or `PT1D`.
        :param bool require_approval: Is approval required for activation. If `true` an `approval_stage` block must be provided.
        :param bool require_justification: Is a justification required during activation of the role.
        :param bool require_multifactor_authentication: Is multi-factor authentication required to activate the role. Conflicts with `required_conditional_access_authentication_context`.
        :param bool require_ticket_info: Is ticket information requrired during activation of the role.
        :param str required_conditional_access_authentication_context: The Entra ID Conditional Access context that must be present for activation. Conflicts with `require_multifactor_authentication`.
        """
        if approval_stage is not None:
            pulumi.set(__self__, "approval_stage", approval_stage)
        if maximum_duration is not None:
            pulumi.set(__self__, "maximum_duration", maximum_duration)
        if require_approval is not None:
            pulumi.set(__self__, "require_approval", require_approval)
        if require_justification is not None:
            pulumi.set(__self__, "require_justification", require_justification)
        if require_multifactor_authentication is not None:
            pulumi.set(__self__, "require_multifactor_authentication", require_multifactor_authentication)
        if require_ticket_info is not None:
            pulumi.set(__self__, "require_ticket_info", require_ticket_info)
        if required_conditional_access_authentication_context is not None:
            pulumi.set(__self__, "required_conditional_access_authentication_context", required_conditional_access_authentication_context)

    @property
    @pulumi.getter(name="approvalStage")
    def approval_stage(self) -> Optional['outputs.RoleManagementPolicyActivationRulesApprovalStage']:
        """
        An `approval_stage` block as defined below.
        """
        return pulumi.get(self, "approval_stage")

    @property
    @pulumi.getter(name="maximumDuration")
    def maximum_duration(self) -> Optional[str]:
        """
        The maximum length of time an activated role can be valid, in an ISO8601 Duration format (e.g. `PT8H`). Valid range is `PT30M` to `PT23H30M`, in 30 minute increments, or `PT1D`.
        """
        return pulumi.get(self, "maximum_duration")

    @property
    @pulumi.getter(name="requireApproval")
    def require_approval(self) -> Optional[bool]:
        """
        Is approval required for activation. If `true` an `approval_stage` block must be provided.
        """
        return pulumi.get(self, "require_approval")

    @property
    @pulumi.getter(name="requireJustification")
    def require_justification(self) -> Optional[bool]:
        """
        Is a justification required during activation of the role.
        """
        return pulumi.get(self, "require_justification")

    @property
    @pulumi.getter(name="requireMultifactorAuthentication")
    def require_multifactor_authentication(self) -> Optional[bool]:
        """
        Is multi-factor authentication required to activate the role. Conflicts with `required_conditional_access_authentication_context`.
        """
        return pulumi.get(self, "require_multifactor_authentication")

    @property
    @pulumi.getter(name="requireTicketInfo")
    def require_ticket_info(self) -> Optional[bool]:
        """
        Is ticket information requrired during activation of the role.
        """
        return pulumi.get(self, "require_ticket_info")

    @property
    @pulumi.getter(name="requiredConditionalAccessAuthenticationContext")
    def required_conditional_access_authentication_context(self) -> Optional[str]:
        """
        The Entra ID Conditional Access context that must be present for activation. Conflicts with `require_multifactor_authentication`.
        """
        return pulumi.get(self, "required_conditional_access_authentication_context")


@pulumi.output_type
class RoleManagementPolicyActivationRulesApprovalStage(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "primaryApprovers":
            suggest = "primary_approvers"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyActivationRulesApprovalStage. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyActivationRulesApprovalStage.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyActivationRulesApprovalStage.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 primary_approvers: Sequence['outputs.RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover']):
        """
        :param Sequence['RoleManagementPolicyActivationRulesApprovalStagePrimaryApproverArgs'] primary_approvers: The IDs of the users or groups who can approve the activation
        """
        pulumi.set(__self__, "primary_approvers", primary_approvers)

    @property
    @pulumi.getter(name="primaryApprovers")
    def primary_approvers(self) -> Sequence['outputs.RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover']:
        """
        The IDs of the users or groups who can approve the activation
        """
        return pulumi.get(self, "primary_approvers")


@pulumi.output_type
class RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "objectId":
            suggest = "object_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyActivationRulesApprovalStagePrimaryApprover.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 object_id: str,
                 type: str):
        """
        :param str object_id: The ID of the object which will act as an approver.
        :param str type: The type of object acting as an approver. Possible options are `User` and `Group`.
        """
        pulumi.set(__self__, "object_id", object_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> str:
        """
        The ID of the object which will act as an approver.
        """
        return pulumi.get(self, "object_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of object acting as an approver. Possible options are `User` and `Group`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class RoleManagementPolicyActiveAssignmentRules(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationRequired":
            suggest = "expiration_required"
        elif key == "expireAfter":
            suggest = "expire_after"
        elif key == "requireJustification":
            suggest = "require_justification"
        elif key == "requireMultifactorAuthentication":
            suggest = "require_multifactor_authentication"
        elif key == "requireTicketInfo":
            suggest = "require_ticket_info"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyActiveAssignmentRules. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyActiveAssignmentRules.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyActiveAssignmentRules.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expiration_required: Optional[bool] = None,
                 expire_after: Optional[str] = None,
                 require_justification: Optional[bool] = None,
                 require_multifactor_authentication: Optional[bool] = None,
                 require_ticket_info: Optional[bool] = None):
        """
        :param bool expiration_required: Must an assignment have an expiry date. `false` allows permanent assignment.
        :param str expire_after: The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
        :param bool require_justification: Is a justification required to create new assignments.
        :param bool require_multifactor_authentication: Is multi-factor authentication required to create new assignments.
        :param bool require_ticket_info: Is ticket information required to create new assignments.
               
               One of `expiration_required` or `expire_after` must be provided.
        """
        if expiration_required is not None:
            pulumi.set(__self__, "expiration_required", expiration_required)
        if expire_after is not None:
            pulumi.set(__self__, "expire_after", expire_after)
        if require_justification is not None:
            pulumi.set(__self__, "require_justification", require_justification)
        if require_multifactor_authentication is not None:
            pulumi.set(__self__, "require_multifactor_authentication", require_multifactor_authentication)
        if require_ticket_info is not None:
            pulumi.set(__self__, "require_ticket_info", require_ticket_info)

    @property
    @pulumi.getter(name="expirationRequired")
    def expiration_required(self) -> Optional[bool]:
        """
        Must an assignment have an expiry date. `false` allows permanent assignment.
        """
        return pulumi.get(self, "expiration_required")

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> Optional[str]:
        """
        The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
        """
        return pulumi.get(self, "expire_after")

    @property
    @pulumi.getter(name="requireJustification")
    def require_justification(self) -> Optional[bool]:
        """
        Is a justification required to create new assignments.
        """
        return pulumi.get(self, "require_justification")

    @property
    @pulumi.getter(name="requireMultifactorAuthentication")
    def require_multifactor_authentication(self) -> Optional[bool]:
        """
        Is multi-factor authentication required to create new assignments.
        """
        return pulumi.get(self, "require_multifactor_authentication")

    @property
    @pulumi.getter(name="requireTicketInfo")
    def require_ticket_info(self) -> Optional[bool]:
        """
        Is ticket information required to create new assignments.

        One of `expiration_required` or `expire_after` must be provided.
        """
        return pulumi.get(self, "require_ticket_info")


@pulumi.output_type
class RoleManagementPolicyEligibleAssignmentRules(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationRequired":
            suggest = "expiration_required"
        elif key == "expireAfter":
            suggest = "expire_after"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyEligibleAssignmentRules. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyEligibleAssignmentRules.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyEligibleAssignmentRules.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 expiration_required: Optional[bool] = None,
                 expire_after: Optional[str] = None):
        """
        :param bool expiration_required: Must an assignment have an expiry date. `false` allows permanent assignment.
        :param str expire_after: The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.
               
               One of `expiration_required` or `expire_after` must be provided.
        """
        if expiration_required is not None:
            pulumi.set(__self__, "expiration_required", expiration_required)
        if expire_after is not None:
            pulumi.set(__self__, "expire_after", expire_after)

    @property
    @pulumi.getter(name="expirationRequired")
    def expiration_required(self) -> Optional[bool]:
        """
        Must an assignment have an expiry date. `false` allows permanent assignment.
        """
        return pulumi.get(self, "expiration_required")

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> Optional[str]:
        """
        The maximum length of time an assignment can be valid, as an ISO8601 duration. Permitted values: `P15D`, `P30D`, `P90D`, `P180D`, or `P365D`.

        One of `expiration_required` or `expire_after` must be provided.
        """
        return pulumi.get(self, "expire_after")


@pulumi.output_type
class RoleManagementPolicyNotificationRules(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "activeAssignments":
            suggest = "active_assignments"
        elif key == "eligibleActivations":
            suggest = "eligible_activations"
        elif key == "eligibleAssignments":
            suggest = "eligible_assignments"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRules. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRules.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRules.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 active_assignments: Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignments'] = None,
                 eligible_activations: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivations'] = None,
                 eligible_assignments: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignments'] = None):
        """
        :param 'RoleManagementPolicyNotificationRulesActiveAssignmentsArgs' active_assignments: A `notification_target` block as defined below to configure notfications on active role assignments.
        :param 'RoleManagementPolicyNotificationRulesEligibleActivationsArgs' eligible_activations: A `notification_target` block as defined below for configuring notifications on activation of eligible role.
        :param 'RoleManagementPolicyNotificationRulesEligibleAssignmentsArgs' eligible_assignments: A `notification_target` block as defined below to configure notification on eligible role assignments.
               
               At least one `notification_target` block must be provided.
        """
        if active_assignments is not None:
            pulumi.set(__self__, "active_assignments", active_assignments)
        if eligible_activations is not None:
            pulumi.set(__self__, "eligible_activations", eligible_activations)
        if eligible_assignments is not None:
            pulumi.set(__self__, "eligible_assignments", eligible_assignments)

    @property
    @pulumi.getter(name="activeAssignments")
    def active_assignments(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignments']:
        """
        A `notification_target` block as defined below to configure notfications on active role assignments.
        """
        return pulumi.get(self, "active_assignments")

    @property
    @pulumi.getter(name="eligibleActivations")
    def eligible_activations(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivations']:
        """
        A `notification_target` block as defined below for configuring notifications on activation of eligible role.
        """
        return pulumi.get(self, "eligible_activations")

    @property
    @pulumi.getter(name="eligibleAssignments")
    def eligible_assignments(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignments']:
        """
        A `notification_target` block as defined below to configure notification on eligible role assignments.

        At least one `notification_target` block must be provided.
        """
        return pulumi.get(self, "eligible_assignments")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesActiveAssignments(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adminNotifications":
            suggest = "admin_notifications"
        elif key == "approverNotifications":
            suggest = "approver_notifications"
        elif key == "assigneeNotifications":
            suggest = "assignee_notifications"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesActiveAssignments. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignments.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignments.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 admin_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications'] = None,
                 approver_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications'] = None,
                 assignee_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications'] = None):
        """
        :param 'RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotificationsArgs' admin_notifications: Admin notification settings
        :param 'RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotificationsArgs' approver_notifications: Approver notification settings
        :param 'RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotificationsArgs' assignee_notifications: Assignee notification settings
        """
        if admin_notifications is not None:
            pulumi.set(__self__, "admin_notifications", admin_notifications)
        if approver_notifications is not None:
            pulumi.set(__self__, "approver_notifications", approver_notifications)
        if assignee_notifications is not None:
            pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications']:
        """
        Admin notification settings
        """
        return pulumi.get(self, "admin_notifications")

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications']:
        """
        Approver notification settings
        """
        return pulumi.get(self, "approver_notifications")

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications']:
        """
        Assignee notification settings
        """
        return pulumi.get(self, "assignee_notifications")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignmentsAdminNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignmentsApproverNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesActiveAssignmentsAssigneeNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleActivations(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adminNotifications":
            suggest = "admin_notifications"
        elif key == "approverNotifications":
            suggest = "approver_notifications"
        elif key == "assigneeNotifications":
            suggest = "assignee_notifications"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleActivations. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivations.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivations.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 admin_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications'] = None,
                 approver_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications'] = None,
                 assignee_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications'] = None):
        """
        :param 'RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotificationsArgs' admin_notifications: Admin notification settings
        :param 'RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotificationsArgs' approver_notifications: Approver notification settings
        :param 'RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotificationsArgs' assignee_notifications: Assignee notification settings
        """
        if admin_notifications is not None:
            pulumi.set(__self__, "admin_notifications", admin_notifications)
        if approver_notifications is not None:
            pulumi.set(__self__, "approver_notifications", approver_notifications)
        if assignee_notifications is not None:
            pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications']:
        """
        Admin notification settings
        """
        return pulumi.get(self, "admin_notifications")

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications']:
        """
        Approver notification settings
        """
        return pulumi.get(self, "approver_notifications")

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications']:
        """
        Assignee notification settings
        """
        return pulumi.get(self, "assignee_notifications")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivationsAdminNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivationsApproverNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleActivationsAssigneeNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleAssignments(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adminNotifications":
            suggest = "admin_notifications"
        elif key == "approverNotifications":
            suggest = "approver_notifications"
        elif key == "assigneeNotifications":
            suggest = "assignee_notifications"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleAssignments. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignments.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignments.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 admin_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications'] = None,
                 approver_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications'] = None,
                 assignee_notifications: Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications'] = None):
        """
        :param 'RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotificationsArgs' admin_notifications: Admin notification settings
        :param 'RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotificationsArgs' approver_notifications: Approver notification settings
        :param 'RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotificationsArgs' assignee_notifications: Assignee notification settings
        """
        if admin_notifications is not None:
            pulumi.set(__self__, "admin_notifications", admin_notifications)
        if approver_notifications is not None:
            pulumi.set(__self__, "approver_notifications", approver_notifications)
        if assignee_notifications is not None:
            pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications']:
        """
        Admin notification settings
        """
        return pulumi.get(self, "admin_notifications")

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications']:
        """
        Approver notification settings
        """
        return pulumi.get(self, "approver_notifications")

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Optional['outputs.RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications']:
        """
        Assignee notification settings
        """
        return pulumi.get(self, "assignee_notifications")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignmentsAdminNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignmentsApproverNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "defaultRecipients":
            suggest = "default_recipients"
        elif key == "notificationLevel":
            suggest = "notification_level"
        elif key == "additionalRecipients":
            suggest = "additional_recipients"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RoleManagementPolicyNotificationRulesEligibleAssignmentsAssigneeNotifications.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 default_recipients: bool,
                 notification_level: str,
                 additional_recipients: Optional[Sequence[str]] = None):
        """
        :param bool default_recipients: Whether the default recipients are notified
        :param str notification_level: What level of notifications are sent
        :param Sequence[str] additional_recipients: The additional recipients to notify
        """
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)
        if additional_recipients is not None:
            pulumi.set(__self__, "additional_recipients", additional_recipients)

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        Whether the default recipients are notified
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        What level of notifications are sent
        """
        return pulumi.get(self, "notification_level")

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Optional[Sequence[str]]:
        """
        The additional recipients to notify
        """
        return pulumi.get(self, "additional_recipients")


@pulumi.output_type
class GetRoleManagementPolicyActivationRuleResult(dict):
    def __init__(__self__, *,
                 approval_stages: Sequence['outputs.GetRoleManagementPolicyActivationRuleApprovalStageResult'],
                 maximum_duration: str,
                 require_approval: bool,
                 require_justification: bool,
                 require_multifactor_authentication: bool,
                 require_ticket_info: bool,
                 required_conditional_access_authentication_context: str):
        """
        :param Sequence['GetRoleManagementPolicyActivationRuleApprovalStageArgs'] approval_stages: An `approval_stage` block as defined below.
        :param str maximum_duration: (String) The maximum length of time an activated role can be valid, in an ISO8601 Duration format.
        :param bool require_approval: (Boolean) Is approval required for activation.
        :param bool require_justification: (Boolean) Is a justification required to create new assignments.
        :param bool require_multifactor_authentication: (Boolean) Is multi-factor authentication required to create new assignments.
        :param bool require_ticket_info: (Boolean) Is ticket information required to create new assignments.
        :param str required_conditional_access_authentication_context: (String) The Entra ID Conditional Access context that must be present for activation.
        """
        pulumi.set(__self__, "approval_stages", approval_stages)
        pulumi.set(__self__, "maximum_duration", maximum_duration)
        pulumi.set(__self__, "require_approval", require_approval)
        pulumi.set(__self__, "require_justification", require_justification)
        pulumi.set(__self__, "require_multifactor_authentication", require_multifactor_authentication)
        pulumi.set(__self__, "require_ticket_info", require_ticket_info)
        pulumi.set(__self__, "required_conditional_access_authentication_context", required_conditional_access_authentication_context)

    @property
    @pulumi.getter(name="approvalStages")
    def approval_stages(self) -> Sequence['outputs.GetRoleManagementPolicyActivationRuleApprovalStageResult']:
        """
        An `approval_stage` block as defined below.
        """
        return pulumi.get(self, "approval_stages")

    @property
    @pulumi.getter(name="maximumDuration")
    def maximum_duration(self) -> str:
        """
        (String) The maximum length of time an activated role can be valid, in an ISO8601 Duration format.
        """
        return pulumi.get(self, "maximum_duration")

    @property
    @pulumi.getter(name="requireApproval")
    def require_approval(self) -> bool:
        """
        (Boolean) Is approval required for activation.
        """
        return pulumi.get(self, "require_approval")

    @property
    @pulumi.getter(name="requireJustification")
    def require_justification(self) -> bool:
        """
        (Boolean) Is a justification required to create new assignments.
        """
        return pulumi.get(self, "require_justification")

    @property
    @pulumi.getter(name="requireMultifactorAuthentication")
    def require_multifactor_authentication(self) -> bool:
        """
        (Boolean) Is multi-factor authentication required to create new assignments.
        """
        return pulumi.get(self, "require_multifactor_authentication")

    @property
    @pulumi.getter(name="requireTicketInfo")
    def require_ticket_info(self) -> bool:
        """
        (Boolean) Is ticket information required to create new assignments.
        """
        return pulumi.get(self, "require_ticket_info")

    @property
    @pulumi.getter(name="requiredConditionalAccessAuthenticationContext")
    def required_conditional_access_authentication_context(self) -> str:
        """
        (String) The Entra ID Conditional Access context that must be present for activation.
        """
        return pulumi.get(self, "required_conditional_access_authentication_context")


@pulumi.output_type
class GetRoleManagementPolicyActivationRuleApprovalStageResult(dict):
    def __init__(__self__, *,
                 primary_approvers: Sequence['outputs.GetRoleManagementPolicyActivationRuleApprovalStagePrimaryApproverResult']):
        """
        :param Sequence['GetRoleManagementPolicyActivationRuleApprovalStagePrimaryApproverArgs'] primary_approvers: The IDs of the users or groups who can approve the activation
        """
        pulumi.set(__self__, "primary_approvers", primary_approvers)

    @property
    @pulumi.getter(name="primaryApprovers")
    def primary_approvers(self) -> Sequence['outputs.GetRoleManagementPolicyActivationRuleApprovalStagePrimaryApproverResult']:
        """
        The IDs of the users or groups who can approve the activation
        """
        return pulumi.get(self, "primary_approvers")


@pulumi.output_type
class GetRoleManagementPolicyActivationRuleApprovalStagePrimaryApproverResult(dict):
    def __init__(__self__, *,
                 object_id: str,
                 type: str):
        """
        :param str object_id: (String) The ID of the object which will act as an approver.
        :param str type: (String) The type of object acting as an approver. Either `User` or `Group`.
        """
        pulumi.set(__self__, "object_id", object_id)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> str:
        """
        (String) The ID of the object which will act as an approver.
        """
        return pulumi.get(self, "object_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        (String) The type of object acting as an approver. Either `User` or `Group`.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetRoleManagementPolicyActiveAssignmentRuleResult(dict):
    def __init__(__self__, *,
                 expiration_required: bool,
                 expire_after: str,
                 require_justification: bool,
                 require_multifactor_authentication: bool,
                 require_ticket_info: bool):
        """
        :param bool expiration_required: (Boolean) Must an assignment have an expiry date.
        :param str expire_after: (String) The maximum length of time an assignment can be valid, as an ISO8601 duration.
        :param bool require_justification: (Boolean) Is a justification required to create new assignments.
        :param bool require_multifactor_authentication: (Boolean) Is multi-factor authentication required to create new assignments.
        :param bool require_ticket_info: (Boolean) Is ticket information required to create new assignments.
        """
        pulumi.set(__self__, "expiration_required", expiration_required)
        pulumi.set(__self__, "expire_after", expire_after)
        pulumi.set(__self__, "require_justification", require_justification)
        pulumi.set(__self__, "require_multifactor_authentication", require_multifactor_authentication)
        pulumi.set(__self__, "require_ticket_info", require_ticket_info)

    @property
    @pulumi.getter(name="expirationRequired")
    def expiration_required(self) -> bool:
        """
        (Boolean) Must an assignment have an expiry date.
        """
        return pulumi.get(self, "expiration_required")

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> str:
        """
        (String) The maximum length of time an assignment can be valid, as an ISO8601 duration.
        """
        return pulumi.get(self, "expire_after")

    @property
    @pulumi.getter(name="requireJustification")
    def require_justification(self) -> bool:
        """
        (Boolean) Is a justification required to create new assignments.
        """
        return pulumi.get(self, "require_justification")

    @property
    @pulumi.getter(name="requireMultifactorAuthentication")
    def require_multifactor_authentication(self) -> bool:
        """
        (Boolean) Is multi-factor authentication required to create new assignments.
        """
        return pulumi.get(self, "require_multifactor_authentication")

    @property
    @pulumi.getter(name="requireTicketInfo")
    def require_ticket_info(self) -> bool:
        """
        (Boolean) Is ticket information required to create new assignments.
        """
        return pulumi.get(self, "require_ticket_info")


@pulumi.output_type
class GetRoleManagementPolicyEligibleAssignmentRuleResult(dict):
    def __init__(__self__, *,
                 expiration_required: bool,
                 expire_after: str):
        """
        :param bool expiration_required: (Boolean) Must an assignment have an expiry date.
        :param str expire_after: (String) The maximum length of time an assignment can be valid, as an ISO8601 duration.
        """
        pulumi.set(__self__, "expiration_required", expiration_required)
        pulumi.set(__self__, "expire_after", expire_after)

    @property
    @pulumi.getter(name="expirationRequired")
    def expiration_required(self) -> bool:
        """
        (Boolean) Must an assignment have an expiry date.
        """
        return pulumi.get(self, "expiration_required")

    @property
    @pulumi.getter(name="expireAfter")
    def expire_after(self) -> str:
        """
        (String) The maximum length of time an assignment can be valid, as an ISO8601 duration.
        """
        return pulumi.get(self, "expire_after")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleResult(dict):
    def __init__(__self__, *,
                 active_assignments: Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentResult'],
                 eligible_activations: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationResult'],
                 eligible_assignments: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentResult']):
        """
        :param Sequence['GetRoleManagementPolicyNotificationRuleActiveAssignmentArgs'] active_assignments: A `notification_target` block as defined below with the details of notfications on active role assignments.
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleActivationArgs'] eligible_activations: A `notification_target` block as defined below with the details of notifications on activation of eligible role.
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleAssignmentArgs'] eligible_assignments: A `notification_target` block as defined below with the details of notifications on eligible role assignments.
        """
        pulumi.set(__self__, "active_assignments", active_assignments)
        pulumi.set(__self__, "eligible_activations", eligible_activations)
        pulumi.set(__self__, "eligible_assignments", eligible_assignments)

    @property
    @pulumi.getter(name="activeAssignments")
    def active_assignments(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentResult']:
        """
        A `notification_target` block as defined below with the details of notfications on active role assignments.
        """
        return pulumi.get(self, "active_assignments")

    @property
    @pulumi.getter(name="eligibleActivations")
    def eligible_activations(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationResult']:
        """
        A `notification_target` block as defined below with the details of notifications on activation of eligible role.
        """
        return pulumi.get(self, "eligible_activations")

    @property
    @pulumi.getter(name="eligibleAssignments")
    def eligible_assignments(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentResult']:
        """
        A `notification_target` block as defined below with the details of notifications on eligible role assignments.
        """
        return pulumi.get(self, "eligible_assignments")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleActiveAssignmentResult(dict):
    def __init__(__self__, *,
                 admin_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentAdminNotificationResult'],
                 approver_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentApproverNotificationResult'],
                 assignee_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentAssigneeNotificationResult']):
        """
        :param Sequence['GetRoleManagementPolicyNotificationRuleActiveAssignmentAdminNotificationArgs'] admin_notifications: A `notification_settings` block as defined above.
        :param Sequence['GetRoleManagementPolicyNotificationRuleActiveAssignmentApproverNotificationArgs'] approver_notifications: A `notification_settings` block as defined above.
        :param Sequence['GetRoleManagementPolicyNotificationRuleActiveAssignmentAssigneeNotificationArgs'] assignee_notifications: A `notification_settings` block as defined above.
        """
        pulumi.set(__self__, "admin_notifications", admin_notifications)
        pulumi.set(__self__, "approver_notifications", approver_notifications)
        pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentAdminNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "admin_notifications")

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentApproverNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "approver_notifications")

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleActiveAssignmentAssigneeNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "assignee_notifications")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleActiveAssignmentAdminNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleActiveAssignmentApproverNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleActiveAssignmentAssigneeNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleActivationResult(dict):
    def __init__(__self__, *,
                 admin_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationAdminNotificationResult'],
                 approver_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationApproverNotificationResult'],
                 assignee_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationAssigneeNotificationResult']):
        """
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleActivationAdminNotificationArgs'] admin_notifications: A `notification_settings` block as defined above.
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleActivationApproverNotificationArgs'] approver_notifications: A `notification_settings` block as defined above.
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleActivationAssigneeNotificationArgs'] assignee_notifications: A `notification_settings` block as defined above.
        """
        pulumi.set(__self__, "admin_notifications", admin_notifications)
        pulumi.set(__self__, "approver_notifications", approver_notifications)
        pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationAdminNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "admin_notifications")

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationApproverNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "approver_notifications")

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleActivationAssigneeNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "assignee_notifications")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleActivationAdminNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleActivationApproverNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleActivationAssigneeNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleAssignmentResult(dict):
    def __init__(__self__, *,
                 admin_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentAdminNotificationResult'],
                 approver_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentApproverNotificationResult'],
                 assignee_notifications: Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentAssigneeNotificationResult']):
        """
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleAssignmentAdminNotificationArgs'] admin_notifications: A `notification_settings` block as defined above.
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleAssignmentApproverNotificationArgs'] approver_notifications: A `notification_settings` block as defined above.
        :param Sequence['GetRoleManagementPolicyNotificationRuleEligibleAssignmentAssigneeNotificationArgs'] assignee_notifications: A `notification_settings` block as defined above.
        """
        pulumi.set(__self__, "admin_notifications", admin_notifications)
        pulumi.set(__self__, "approver_notifications", approver_notifications)
        pulumi.set(__self__, "assignee_notifications", assignee_notifications)

    @property
    @pulumi.getter(name="adminNotifications")
    def admin_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentAdminNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "admin_notifications")

    @property
    @pulumi.getter(name="approverNotifications")
    def approver_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentApproverNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "approver_notifications")

    @property
    @pulumi.getter(name="assigneeNotifications")
    def assignee_notifications(self) -> Sequence['outputs.GetRoleManagementPolicyNotificationRuleEligibleAssignmentAssigneeNotificationResult']:
        """
        A `notification_settings` block as defined above.
        """
        return pulumi.get(self, "assignee_notifications")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleAssignmentAdminNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleAssignmentApproverNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")


@pulumi.output_type
class GetRoleManagementPolicyNotificationRuleEligibleAssignmentAssigneeNotificationResult(dict):
    def __init__(__self__, *,
                 additional_recipients: Sequence[str],
                 default_recipients: bool,
                 notification_level: str):
        """
        :param Sequence[str] additional_recipients: A list of additional email addresses that will receive these notifications.
        :param bool default_recipients: (Boolean) Should the default recipients receive these notifications.
        :param str notification_level: (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        pulumi.set(__self__, "additional_recipients", additional_recipients)
        pulumi.set(__self__, "default_recipients", default_recipients)
        pulumi.set(__self__, "notification_level", notification_level)

    @property
    @pulumi.getter(name="additionalRecipients")
    def additional_recipients(self) -> Sequence[str]:
        """
        A list of additional email addresses that will receive these notifications.
        """
        return pulumi.get(self, "additional_recipients")

    @property
    @pulumi.getter(name="defaultRecipients")
    def default_recipients(self) -> bool:
        """
        (Boolean) Should the default recipients receive these notifications.
        """
        return pulumi.get(self, "default_recipients")

    @property
    @pulumi.getter(name="notificationLevel")
    def notification_level(self) -> str:
        """
        (String) What level of notifications should be sent. Either `All` or `Critical`.
        """
        return pulumi.get(self, "notification_level")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetVirtualMachineManagerInventoryItemsInventoryItemResult',
]

@pulumi.output_type
class GetVirtualMachineManagerInventoryItemsInventoryItemResult(dict):
    def __init__(__self__, *,
                 id: str,
                 name: str,
                 uuid: str):
        """
        :param str id: The ID of the System Center Virtual Machine Manager Inventory Item.
        :param str name: The name of the System Center Virtual Machine Manager Inventory Item.
        :param str uuid: The UUID of the System Center Virtual Machine Manager Inventory Item that is assigned by System Center Virtual Machine Manager.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "uuid", uuid)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the System Center Virtual Machine Manager Inventory Item.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the System Center Virtual Machine Manager Inventory Item.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def uuid(self) -> str:
        """
        The UUID of the System Center Virtual Machine Manager Inventory Item that is assigned by System Center Virtual Machine Manager.
        """
        return pulumi.get(self, "uuid")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ManagedHardwareSecurityModuleArgs', 'ManagedHardwareSecurityModule']

@pulumi.input_type
class ManagedHardwareSecurityModuleArgs:
    def __init__(__self__, *,
                 admin_object_ids: pulumi.Input[Sequence[pulumi.Input[str]]],
                 resource_group_name: pulumi.Input[str],
                 sku_name: pulumi.Input[str],
                 tenant_id: pulumi.Input[str],
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_acls: Optional[pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs']] = None,
                 public_network_access_enabled: Optional[pulumi.Input[bool]] = None,
                 purge_protection_enabled: Optional[pulumi.Input[bool]] = None,
                 security_domain_key_vault_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 security_domain_quorum: Optional[pulumi.Input[int]] = None,
                 soft_delete_retention_days: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ManagedHardwareSecurityModule resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] admin_object_ids: Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] sku_name: The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs'] network_acls: A `network_acls` block as defined below.
        :param pulumi.Input[bool] public_network_access_enabled: Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] purge_protection_enabled: Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_domain_key_vault_certificate_ids: A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        :param pulumi.Input[int] security_domain_quorum: Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        :param pulumi.Input[int] soft_delete_retention_days: The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "admin_object_ids", admin_object_ids)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "sku_name", sku_name)
        pulumi.set(__self__, "tenant_id", tenant_id)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_acls is not None:
            pulumi.set(__self__, "network_acls", network_acls)
        if public_network_access_enabled is not None:
            pulumi.set(__self__, "public_network_access_enabled", public_network_access_enabled)
        if purge_protection_enabled is not None:
            pulumi.set(__self__, "purge_protection_enabled", purge_protection_enabled)
        if security_domain_key_vault_certificate_ids is not None:
            pulumi.set(__self__, "security_domain_key_vault_certificate_ids", security_domain_key_vault_certificate_ids)
        if security_domain_quorum is not None:
            pulumi.set(__self__, "security_domain_quorum", security_domain_quorum)
        if soft_delete_retention_days is not None:
            pulumi.set(__self__, "soft_delete_retention_days", soft_delete_retention_days)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="adminObjectIds")
    def admin_object_ids(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "admin_object_ids")

    @admin_object_ids.setter
    def admin_object_ids(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "admin_object_ids", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Input[str]:
        """
        The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "sku_name", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[str]:
        """
        The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "tenant_id", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkAcls")
    def network_acls(self) -> Optional[pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs']]:
        """
        A `network_acls` block as defined below.
        """
        return pulumi.get(self, "network_acls")

    @network_acls.setter
    def network_acls(self, value: Optional[pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs']]):
        pulumi.set(self, "network_acls", value)

    @property
    @pulumi.getter(name="publicNetworkAccessEnabled")
    def public_network_access_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "public_network_access_enabled")

    @public_network_access_enabled.setter
    def public_network_access_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "public_network_access_enabled", value)

    @property
    @pulumi.getter(name="purgeProtectionEnabled")
    def purge_protection_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "purge_protection_enabled")

    @purge_protection_enabled.setter
    def purge_protection_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "purge_protection_enabled", value)

    @property
    @pulumi.getter(name="securityDomainKeyVaultCertificateIds")
    def security_domain_key_vault_certificate_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        """
        return pulumi.get(self, "security_domain_key_vault_certificate_ids")

    @security_domain_key_vault_certificate_ids.setter
    def security_domain_key_vault_certificate_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_domain_key_vault_certificate_ids", value)

    @property
    @pulumi.getter(name="securityDomainQuorum")
    def security_domain_quorum(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        """
        return pulumi.get(self, "security_domain_quorum")

    @security_domain_quorum.setter
    def security_domain_quorum(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "security_domain_quorum", value)

    @property
    @pulumi.getter(name="softDeleteRetentionDays")
    def soft_delete_retention_days(self) -> Optional[pulumi.Input[int]]:
        """
        The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "soft_delete_retention_days")

    @soft_delete_retention_days.setter
    def soft_delete_retention_days(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "soft_delete_retention_days", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ManagedHardwareSecurityModuleState:
    def __init__(__self__, *,
                 admin_object_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 hsm_uri: Optional[pulumi.Input[str]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_acls: Optional[pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs']] = None,
                 public_network_access_enabled: Optional[pulumi.Input[bool]] = None,
                 purge_protection_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 security_domain_encrypted_data: Optional[pulumi.Input[str]] = None,
                 security_domain_key_vault_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 security_domain_quorum: Optional[pulumi.Input[int]] = None,
                 sku_name: Optional[pulumi.Input[str]] = None,
                 soft_delete_retention_days: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ManagedHardwareSecurityModule resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] admin_object_ids: Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] hsm_uri: The URI of the Key Vault Managed Hardware Security Module, used for performing operations on keys.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs'] network_acls: A `network_acls` block as defined below.
        :param pulumi.Input[bool] public_network_access_enabled: Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] purge_protection_enabled: Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] security_domain_encrypted_data: This attribute can be used for disaster recovery or when creating another Managed HSM that shares the same security domain.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_domain_key_vault_certificate_ids: A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        :param pulumi.Input[int] security_domain_quorum: Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        :param pulumi.Input[str] sku_name: The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        :param pulumi.Input[int] soft_delete_retention_days: The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        if admin_object_ids is not None:
            pulumi.set(__self__, "admin_object_ids", admin_object_ids)
        if hsm_uri is not None:
            pulumi.set(__self__, "hsm_uri", hsm_uri)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_acls is not None:
            pulumi.set(__self__, "network_acls", network_acls)
        if public_network_access_enabled is not None:
            pulumi.set(__self__, "public_network_access_enabled", public_network_access_enabled)
        if purge_protection_enabled is not None:
            pulumi.set(__self__, "purge_protection_enabled", purge_protection_enabled)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if security_domain_encrypted_data is not None:
            pulumi.set(__self__, "security_domain_encrypted_data", security_domain_encrypted_data)
        if security_domain_key_vault_certificate_ids is not None:
            pulumi.set(__self__, "security_domain_key_vault_certificate_ids", security_domain_key_vault_certificate_ids)
        if security_domain_quorum is not None:
            pulumi.set(__self__, "security_domain_quorum", security_domain_quorum)
        if sku_name is not None:
            pulumi.set(__self__, "sku_name", sku_name)
        if soft_delete_retention_days is not None:
            pulumi.set(__self__, "soft_delete_retention_days", soft_delete_retention_days)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="adminObjectIds")
    def admin_object_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "admin_object_ids")

    @admin_object_ids.setter
    def admin_object_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "admin_object_ids", value)

    @property
    @pulumi.getter(name="hsmUri")
    def hsm_uri(self) -> Optional[pulumi.Input[str]]:
        """
        The URI of the Key Vault Managed Hardware Security Module, used for performing operations on keys.
        """
        return pulumi.get(self, "hsm_uri")

    @hsm_uri.setter
    def hsm_uri(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "hsm_uri", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkAcls")
    def network_acls(self) -> Optional[pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs']]:
        """
        A `network_acls` block as defined below.
        """
        return pulumi.get(self, "network_acls")

    @network_acls.setter
    def network_acls(self, value: Optional[pulumi.Input['ManagedHardwareSecurityModuleNetworkAclsArgs']]):
        pulumi.set(self, "network_acls", value)

    @property
    @pulumi.getter(name="publicNetworkAccessEnabled")
    def public_network_access_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "public_network_access_enabled")

    @public_network_access_enabled.setter
    def public_network_access_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "public_network_access_enabled", value)

    @property
    @pulumi.getter(name="purgeProtectionEnabled")
    def purge_protection_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "purge_protection_enabled")

    @purge_protection_enabled.setter
    def purge_protection_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "purge_protection_enabled", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="securityDomainEncryptedData")
    def security_domain_encrypted_data(self) -> Optional[pulumi.Input[str]]:
        """
        This attribute can be used for disaster recovery or when creating another Managed HSM that shares the same security domain.
        """
        return pulumi.get(self, "security_domain_encrypted_data")

    @security_domain_encrypted_data.setter
    def security_domain_encrypted_data(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "security_domain_encrypted_data", value)

    @property
    @pulumi.getter(name="securityDomainKeyVaultCertificateIds")
    def security_domain_key_vault_certificate_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        """
        return pulumi.get(self, "security_domain_key_vault_certificate_ids")

    @security_domain_key_vault_certificate_ids.setter
    def security_domain_key_vault_certificate_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "security_domain_key_vault_certificate_ids", value)

    @property
    @pulumi.getter(name="securityDomainQuorum")
    def security_domain_quorum(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        """
        return pulumi.get(self, "security_domain_quorum")

    @security_domain_quorum.setter
    def security_domain_quorum(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "security_domain_quorum", value)

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sku_name", value)

    @property
    @pulumi.getter(name="softDeleteRetentionDays")
    def soft_delete_retention_days(self) -> Optional[pulumi.Input[int]]:
        """
        The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "soft_delete_retention_days")

    @soft_delete_retention_days.setter
    def soft_delete_retention_days(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "soft_delete_retention_days", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


class ManagedHardwareSecurityModule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_object_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_acls: Optional[pulumi.Input[Union['ManagedHardwareSecurityModuleNetworkAclsArgs', 'ManagedHardwareSecurityModuleNetworkAclsArgsDict']]] = None,
                 public_network_access_enabled: Optional[pulumi.Input[bool]] = None,
                 purge_protection_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 security_domain_key_vault_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 security_domain_quorum: Optional[pulumi.Input[int]] = None,
                 sku_name: Optional[pulumi.Input[str]] = None,
                 soft_delete_retention_days: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Key Vault Managed Hardware Security Module.

        > **Note:** The Azure Provider includes a Feature Toggle which will purge a Key Vault Managed Hardware Security Module resource on destroy, rather than the default soft-delete. See `purge_soft_deleted_hardware_security_modules_on_destroy` for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_managed_hardware_security_module = azure.keyvault.ManagedHardwareSecurityModule("example",
            name="exampleKVHsm",
            resource_group_name=example.name,
            location=example.location,
            sku_name="Standard_B1",
            purge_protection_enabled=False,
            soft_delete_retention_days=90,
            tenant_id=current.tenant_id,
            admin_object_ids=[current.object_id],
            tags={
                "Env": "Test",
            })
        ```

        ## Import

        Key Vault Managed Hardware Security Module can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:keyvault/managedHardwareSecurityModule:ManagedHardwareSecurityModule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.KeyVault/managedHSMs/hsm1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] admin_object_ids: Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ManagedHardwareSecurityModuleNetworkAclsArgs', 'ManagedHardwareSecurityModuleNetworkAclsArgsDict']] network_acls: A `network_acls` block as defined below.
        :param pulumi.Input[bool] public_network_access_enabled: Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] purge_protection_enabled: Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_domain_key_vault_certificate_ids: A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        :param pulumi.Input[int] security_domain_quorum: Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        :param pulumi.Input[str] sku_name: The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        :param pulumi.Input[int] soft_delete_retention_days: The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ManagedHardwareSecurityModuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Key Vault Managed Hardware Security Module.

        > **Note:** The Azure Provider includes a Feature Toggle which will purge a Key Vault Managed Hardware Security Module resource on destroy, rather than the default soft-delete. See `purge_soft_deleted_hardware_security_modules_on_destroy` for more information.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        current = azure.core.get_client_config()
        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_managed_hardware_security_module = azure.keyvault.ManagedHardwareSecurityModule("example",
            name="exampleKVHsm",
            resource_group_name=example.name,
            location=example.location,
            sku_name="Standard_B1",
            purge_protection_enabled=False,
            soft_delete_retention_days=90,
            tenant_id=current.tenant_id,
            admin_object_ids=[current.object_id],
            tags={
                "Env": "Test",
            })
        ```

        ## Import

        Key Vault Managed Hardware Security Module can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:keyvault/managedHardwareSecurityModule:ManagedHardwareSecurityModule example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.KeyVault/managedHSMs/hsm1
        ```

        :param str resource_name: The name of the resource.
        :param ManagedHardwareSecurityModuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ManagedHardwareSecurityModuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_object_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_acls: Optional[pulumi.Input[Union['ManagedHardwareSecurityModuleNetworkAclsArgs', 'ManagedHardwareSecurityModuleNetworkAclsArgsDict']]] = None,
                 public_network_access_enabled: Optional[pulumi.Input[bool]] = None,
                 purge_protection_enabled: Optional[pulumi.Input[bool]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 security_domain_key_vault_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 security_domain_quorum: Optional[pulumi.Input[int]] = None,
                 sku_name: Optional[pulumi.Input[str]] = None,
                 soft_delete_retention_days: Optional[pulumi.Input[int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ManagedHardwareSecurityModuleArgs.__new__(ManagedHardwareSecurityModuleArgs)

            if admin_object_ids is None and not opts.urn:
                raise TypeError("Missing required property 'admin_object_ids'")
            __props__.__dict__["admin_object_ids"] = admin_object_ids
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            __props__.__dict__["network_acls"] = network_acls
            __props__.__dict__["public_network_access_enabled"] = public_network_access_enabled
            __props__.__dict__["purge_protection_enabled"] = purge_protection_enabled
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["security_domain_key_vault_certificate_ids"] = security_domain_key_vault_certificate_ids
            __props__.__dict__["security_domain_quorum"] = security_domain_quorum
            if sku_name is None and not opts.urn:
                raise TypeError("Missing required property 'sku_name'")
            __props__.__dict__["sku_name"] = sku_name
            __props__.__dict__["soft_delete_retention_days"] = soft_delete_retention_days
            __props__.__dict__["tags"] = tags
            if tenant_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenant_id'")
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["hsm_uri"] = None
            __props__.__dict__["security_domain_encrypted_data"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["securityDomainEncryptedData"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ManagedHardwareSecurityModule, __self__).__init__(
            'azure:keyvault/managedHardwareSecurityModule:ManagedHardwareSecurityModule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            admin_object_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            hsm_uri: Optional[pulumi.Input[str]] = None,
            location: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            network_acls: Optional[pulumi.Input[Union['ManagedHardwareSecurityModuleNetworkAclsArgs', 'ManagedHardwareSecurityModuleNetworkAclsArgsDict']]] = None,
            public_network_access_enabled: Optional[pulumi.Input[bool]] = None,
            purge_protection_enabled: Optional[pulumi.Input[bool]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            security_domain_encrypted_data: Optional[pulumi.Input[str]] = None,
            security_domain_key_vault_certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            security_domain_quorum: Optional[pulumi.Input[int]] = None,
            sku_name: Optional[pulumi.Input[str]] = None,
            soft_delete_retention_days: Optional[pulumi.Input[int]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tenant_id: Optional[pulumi.Input[str]] = None) -> 'ManagedHardwareSecurityModule':
        """
        Get an existing ManagedHardwareSecurityModule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] admin_object_ids: Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] hsm_uri: The URI of the Key Vault Managed Hardware Security Module, used for performing operations on keys.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ManagedHardwareSecurityModuleNetworkAclsArgs', 'ManagedHardwareSecurityModuleNetworkAclsArgsDict']] network_acls: A `network_acls` block as defined below.
        :param pulumi.Input[bool] public_network_access_enabled: Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        :param pulumi.Input[bool] purge_protection_enabled: Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        :param pulumi.Input[str] security_domain_encrypted_data: This attribute can be used for disaster recovery or when creating another Managed HSM that shares the same security domain.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] security_domain_key_vault_certificate_ids: A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        :param pulumi.Input[int] security_domain_quorum: Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        :param pulumi.Input[str] sku_name: The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        :param pulumi.Input[int] soft_delete_retention_days: The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[str] tenant_id: The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ManagedHardwareSecurityModuleState.__new__(_ManagedHardwareSecurityModuleState)

        __props__.__dict__["admin_object_ids"] = admin_object_ids
        __props__.__dict__["hsm_uri"] = hsm_uri
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["network_acls"] = network_acls
        __props__.__dict__["public_network_access_enabled"] = public_network_access_enabled
        __props__.__dict__["purge_protection_enabled"] = purge_protection_enabled
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["security_domain_encrypted_data"] = security_domain_encrypted_data
        __props__.__dict__["security_domain_key_vault_certificate_ids"] = security_domain_key_vault_certificate_ids
        __props__.__dict__["security_domain_quorum"] = security_domain_quorum
        __props__.__dict__["sku_name"] = sku_name
        __props__.__dict__["soft_delete_retention_days"] = soft_delete_retention_days
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tenant_id"] = tenant_id
        return ManagedHardwareSecurityModule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="adminObjectIds")
    def admin_object_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        Specifies a list of administrators object IDs for the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "admin_object_ids")

    @property
    @pulumi.getter(name="hsmUri")
    def hsm_uri(self) -> pulumi.Output[str]:
        """
        The URI of the Key Vault Managed Hardware Security Module, used for performing operations on keys.
        """
        return pulumi.get(self, "hsm_uri")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Specifies the name of the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkAcls")
    def network_acls(self) -> pulumi.Output['outputs.ManagedHardwareSecurityModuleNetworkAcls']:
        """
        A `network_acls` block as defined below.
        """
        return pulumi.get(self, "network_acls")

    @property
    @pulumi.getter(name="publicNetworkAccessEnabled")
    def public_network_access_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether traffic from public networks is permitted. Defaults to `true`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "public_network_access_enabled")

    @property
    @pulumi.getter(name="purgeProtectionEnabled")
    def purge_protection_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Is Purge Protection enabled for this Key Vault Managed Hardware Security Module? Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "purge_protection_enabled")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the resource group in which to create the Key Vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="securityDomainEncryptedData")
    def security_domain_encrypted_data(self) -> pulumi.Output[str]:
        """
        This attribute can be used for disaster recovery or when creating another Managed HSM that shares the same security domain.
        """
        return pulumi.get(self, "security_domain_encrypted_data")

    @property
    @pulumi.getter(name="securityDomainKeyVaultCertificateIds")
    def security_domain_key_vault_certificate_ids(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of KeyVault certificates resource IDs (minimum of three and up to a maximum of 10) to activate this Managed HSM. More information see [activate-your-managed-hsm](https://learn.microsoft.com/azure/key-vault/managed-hsm/quick-create-cli#activate-your-managed-hsm)
        """
        return pulumi.get(self, "security_domain_key_vault_certificate_ids")

    @property
    @pulumi.getter(name="securityDomainQuorum")
    def security_domain_quorum(self) -> pulumi.Output[Optional[int]]:
        """
        Specifies the minimum number of shares required to decrypt the security domain for recovery. This is required when `security_domain_key_vault_certificate_ids` is specified. Valid values are between 2 and 10.
        """
        return pulumi.get(self, "security_domain_quorum")

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Output[str]:
        """
        The Name of the SKU used for this Key Vault Managed Hardware Security Module. Possible value is `Standard_B1`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sku_name")

    @property
    @pulumi.getter(name="softDeleteRetentionDays")
    def soft_delete_retention_days(self) -> pulumi.Output[Optional[int]]:
        """
        The number of days that items should be retained for once soft-deleted. This value can be between `7` and `90` days. Defaults to `90`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "soft_delete_retention_days")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[str]:
        """
        The Azure Active Directory Tenant ID that should be used for authenticating requests to the key vault Managed Hardware Security Module. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "tenant_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNetworkSimPolicyResult',
    'AwaitableGetNetworkSimPolicyResult',
    'get_network_sim_policy',
    'get_network_sim_policy_output',
]

@pulumi.output_type
class GetNetworkSimPolicyResult:
    """
    A collection of values returned by getNetworkSimPolicy.
    """
    def __init__(__self__, default_slice_id=None, id=None, location=None, mobile_network_id=None, name=None, rat_frequency_selection_priority_index=None, registration_timer_in_seconds=None, slices=None, tags=None, user_equipment_aggregate_maximum_bit_rates=None):
        if default_slice_id and not isinstance(default_slice_id, str):
            raise TypeError("Expected argument 'default_slice_id' to be a str")
        pulumi.set(__self__, "default_slice_id", default_slice_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if mobile_network_id and not isinstance(mobile_network_id, str):
            raise TypeError("Expected argument 'mobile_network_id' to be a str")
        pulumi.set(__self__, "mobile_network_id", mobile_network_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if rat_frequency_selection_priority_index and not isinstance(rat_frequency_selection_priority_index, int):
            raise TypeError("Expected argument 'rat_frequency_selection_priority_index' to be a int")
        pulumi.set(__self__, "rat_frequency_selection_priority_index", rat_frequency_selection_priority_index)
        if registration_timer_in_seconds and not isinstance(registration_timer_in_seconds, int):
            raise TypeError("Expected argument 'registration_timer_in_seconds' to be a int")
        pulumi.set(__self__, "registration_timer_in_seconds", registration_timer_in_seconds)
        if slices and not isinstance(slices, list):
            raise TypeError("Expected argument 'slices' to be a list")
        pulumi.set(__self__, "slices", slices)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if user_equipment_aggregate_maximum_bit_rates and not isinstance(user_equipment_aggregate_maximum_bit_rates, list):
            raise TypeError("Expected argument 'user_equipment_aggregate_maximum_bit_rates' to be a list")
        pulumi.set(__self__, "user_equipment_aggregate_maximum_bit_rates", user_equipment_aggregate_maximum_bit_rates)

    @property
    @pulumi.getter(name="defaultSliceId")
    def default_slice_id(self) -> str:
        """
        The ID of default slice to use if the UE does not explicitly specify it.
        """
        return pulumi.get(self, "default_slice_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The Azure Region where the Mobile Network Sim Policy should exist.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="mobileNetworkId")
    def mobile_network_id(self) -> str:
        return pulumi.get(self, "mobile_network_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ratFrequencySelectionPriorityIndex")
    def rat_frequency_selection_priority_index(self) -> int:
        """
        RAT/Frequency Selection Priority Index, defined in 3GPP TS 36.413.
        """
        return pulumi.get(self, "rat_frequency_selection_priority_index")

    @property
    @pulumi.getter(name="registrationTimerInSeconds")
    def registration_timer_in_seconds(self) -> int:
        """
        Interval for the UE periodic registration update procedure.
        """
        return pulumi.get(self, "registration_timer_in_seconds")

    @property
    @pulumi.getter
    def slices(self) -> Sequence['outputs.GetNetworkSimPolicySliceResult']:
        """
        An array of `slice` block as defined below. The allowed slices and the settings to use for them.
        """
        return pulumi.get(self, "slices")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags which should be assigned to the Mobile Network Sim Policies.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="userEquipmentAggregateMaximumBitRates")
    def user_equipment_aggregate_maximum_bit_rates(self) -> Sequence['outputs.GetNetworkSimPolicyUserEquipmentAggregateMaximumBitRateResult']:
        """
        A `user_equipment_aggregate_maximum_bit_rate` block as defined below.
        """
        return pulumi.get(self, "user_equipment_aggregate_maximum_bit_rates")


class AwaitableGetNetworkSimPolicyResult(GetNetworkSimPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkSimPolicyResult(
            default_slice_id=self.default_slice_id,
            id=self.id,
            location=self.location,
            mobile_network_id=self.mobile_network_id,
            name=self.name,
            rat_frequency_selection_priority_index=self.rat_frequency_selection_priority_index,
            registration_timer_in_seconds=self.registration_timer_in_seconds,
            slices=self.slices,
            tags=self.tags,
            user_equipment_aggregate_maximum_bit_rates=self.user_equipment_aggregate_maximum_bit_rates)


def get_network_sim_policy(mobile_network_id: Optional[str] = None,
                           name: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkSimPolicyResult:
    """
    Get information about a Mobile Network Sim Policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.mobile.get_network(name="example-mn",
        resource_group_name="example-rg")
    example_get_network_sim_policy = azure.mobile.get_network_sim_policy(name="example-mnsp",
        mobile_network_id=example.id)
    ```


    :param str mobile_network_id: The ID of the Mobile Network which the Sim Policy belongs to.
    :param str name: The name which should be used for this Mobile Network Sim Policies.
    """
    __args__ = dict()
    __args__['mobileNetworkId'] = mobile_network_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:mobile/getNetworkSimPolicy:getNetworkSimPolicy', __args__, opts=opts, typ=GetNetworkSimPolicyResult).value

    return AwaitableGetNetworkSimPolicyResult(
        default_slice_id=pulumi.get(__ret__, 'default_slice_id'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'),
        mobile_network_id=pulumi.get(__ret__, 'mobile_network_id'),
        name=pulumi.get(__ret__, 'name'),
        rat_frequency_selection_priority_index=pulumi.get(__ret__, 'rat_frequency_selection_priority_index'),
        registration_timer_in_seconds=pulumi.get(__ret__, 'registration_timer_in_seconds'),
        slices=pulumi.get(__ret__, 'slices'),
        tags=pulumi.get(__ret__, 'tags'),
        user_equipment_aggregate_maximum_bit_rates=pulumi.get(__ret__, 'user_equipment_aggregate_maximum_bit_rates'))
def get_network_sim_policy_output(mobile_network_id: Optional[pulumi.Input[str]] = None,
                                  name: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkSimPolicyResult]:
    """
    Get information about a Mobile Network Sim Policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.mobile.get_network(name="example-mn",
        resource_group_name="example-rg")
    example_get_network_sim_policy = azure.mobile.get_network_sim_policy(name="example-mnsp",
        mobile_network_id=example.id)
    ```


    :param str mobile_network_id: The ID of the Mobile Network which the Sim Policy belongs to.
    :param str name: The name which should be used for this Mobile Network Sim Policies.
    """
    __args__ = dict()
    __args__['mobileNetworkId'] = mobile_network_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:mobile/getNetworkSimPolicy:getNetworkSimPolicy', __args__, opts=opts, typ=GetNetworkSimPolicyResult)
    return __ret__.apply(lambda __response__: GetNetworkSimPolicyResult(
        default_slice_id=pulumi.get(__response__, 'default_slice_id'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location'),
        mobile_network_id=pulumi.get(__response__, 'mobile_network_id'),
        name=pulumi.get(__response__, 'name'),
        rat_frequency_selection_priority_index=pulumi.get(__response__, 'rat_frequency_selection_priority_index'),
        registration_timer_in_seconds=pulumi.get(__response__, 'registration_timer_in_seconds'),
        slices=pulumi.get(__response__, 'slices'),
        tags=pulumi.get(__response__, 'tags'),
        user_equipment_aggregate_maximum_bit_rates=pulumi.get(__response__, 'user_equipment_aggregate_maximum_bit_rates')))
